"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _reactReconciler = require("react-reconciler");

var _reactReconciler2 = _interopRequireDefault(_reactReconciler);

var _emptyObject = require("fbjs/lib/emptyObject");

var _emptyObject2 = _interopRequireDefault(_emptyObject);

var _createElement = require("./createElement");

var _diffProperties = require("../util/diffProperties");

var _diffProperties2 = _interopRequireDefault(_diffProperties);

var _stateManagement = require("../util/stateManagement");

var _stateManagement2 = _interopRequireDefault(_stateManagement);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var ReconcilerConfig = {
  appendInitialChild: function appendInitialChild(parentInstance, child) {
    if (parentInstance.appendChild) {
      parentInstance.appendChild(child);
    } else {
      parentInstance.universe = Object.assign(parentInstance.universe || {}, child);
    }
  },
  createInstance: function createInstance(type, props, internalInstanceHandle) {
    return (0, _createElement.createElement)(type, props, internalInstanceHandle);
  },
  createTextInstance: function createTextInstance(text, rootContainerInstance, internalInstanceHandle) {
    return text;
  },
  finalizeInitialChildren: function finalizeInitialChildren(wordElement, type, props) {
    return false;
  },
  getPublicInstance: function getPublicInstance(inst) {
    return inst;
  },
  prepareForCommit: function prepareForCommit() {
    // noop
  },
  prepareUpdate: function prepareUpdate(wordElement, type, oldProps, newProps) {
    return (0, _diffProperties2.default)(type, oldProps, newProps);
  },
  resetAfterCommit: function resetAfterCommit() {
    // noop
  },
  resetTextContent: function resetTextContent(wordElement) {
    // noop
  },
  getRootHostContext: function getRootHostContext(rootInstance) {
    // You can use this 'rootInstance' to pass data from the roots.
  },
  getChildHostContext: function getChildHostContext() {
    return _emptyObject2.default;
  },
  shouldSetTextContent: function shouldSetTextContent(type, props) {
    return false;
  },


  now: function now() {
    return Date.now();
  },

  useSyncScheduling: true,

  mutation: {
    appendChild: function appendChild(parentInstance, child) {
      if (parentInstance.appendChild) {
        parentInstance.appendChild(child);
      } else {
        parentInstance.universe = Object.assign(parentInstance.universe || {}, child);
      }
    },
    appendChildToContainer: function appendChildToContainer(parentInstance, child) {
      if (parentInstance.appendChild) {
        parentInstance.appendChild(child);
      } else {
        parentInstance.universe = Object.assign(parentInstance.universe || {}, child);
      }
    },
    removeChild: function removeChild(parentInstance, child) {
      parentInstance.removeChild(child);
    },
    removeChildFromContainer: function removeChildFromContainer(parentInstance, child) {
      parentInstance.removeChild(child);
    },
    insertBefore: function insertBefore(parentInstance, child, beforeChild) {
      // noob
    },
    commitUpdate: function commitUpdate(instance, updatePayload, type, oldProps, newProps) {
      var universe = instance.root;
      instance.props = newProps;
      if (type === "light") {
        _stateManagement2.default.updateUniverse(universe, newProps);
      }
    },
    commitMount: function commitMount(instance, updatePayload, type, oldProps, newProps) {
      // noop
    },
    commitTextUpdate: function commitTextUpdate(textInstance, oldText, newText) {
      textInstance.children = newText;
    }
  }
};

var ReactDMX = (0, _reactReconciler2.default)(ReconcilerConfig);

exports.default = ReactDMX;